pub struct MazeSolutionWasm {
pub solution: MazeSolution,
}Expand description
Web assembly representation of a maze solution
Fields
solution: MazeSolutionImplementations
Sourceimpl MazeSolutionWasm
impl MazeSolutionWasm
Sourcepub fn get_path_points(&self) -> Array
pub fn get_path_points(&self) -> Array
Returns the array of points (if any) associated with the maze solution
Returns
This function will return an array of Javascript objects defining each point in the solution. Each solution point object has the folllowing properties:
row- zero-based row index for the solution pointcol- zero-based column index for the solution point
Examples
Initialize a maze from a JSON string, then attempt to solve it and, if successful, print the maze solution path’s points
// Javascript <script> content:
import init, { MazeWasm } from 'maze_wasm.js';
async function run() {
await init();
try {
let maze = new MazeWasm();
maze.from_json(`{
\"id\":\"maze_id\",
\"name\":\"test\",
\"definition\": {
\"grid\":[
[\"S\", \"W\", \" \", \" \", \"W\"],
[\" \", \"W\", \" \", \"W\", \" \"],
[\" \", \" \", \" \", \"W\", \"F\"],
[\"W\", \" \", \"W\", \" \", \" \"],
[\" \", \" \", \" \", \"W\", \" \"],
[\"W\", \"W\", \" \", \" \", \" \"],
[\"W\", \"W\", \" \", \"W\", \" \"]
]
}}`);
let solution = maze.solve();
let solutionPoints = solution.get_path_points();
console.log("Successfully solved maze. Solution points are: ", solutionPoints);
} catch (e) {
console.error("Operation failed: ", e);
}
}
run();Trait Implementations
Sourceimpl From<MazeSolutionWasm> for JsValue
impl From<MazeSolutionWasm> for JsValue
Sourcefn from(value: MazeSolutionWasm) -> Self
fn from(value: MazeSolutionWasm) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for MazeSolutionWasm
impl FromWasmAbi for MazeSolutionWasm
Sourceimpl IntoWasmAbi for MazeSolutionWasm
impl IntoWasmAbi for MazeSolutionWasm
Sourceimpl OptionFromWasmAbi for MazeSolutionWasm
impl OptionFromWasmAbi for MazeSolutionWasm
Sourceimpl OptionIntoWasmAbi for MazeSolutionWasm
impl OptionIntoWasmAbi for MazeSolutionWasm
Sourceimpl RefFromWasmAbi for MazeSolutionWasm
impl RefFromWasmAbi for MazeSolutionWasm
Sourcetype Anchor = RcRef<MazeSolutionWasm>
type Anchor = RcRef<MazeSolutionWasm>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl RefMutFromWasmAbi for MazeSolutionWasm
impl RefMutFromWasmAbi for MazeSolutionWasm
Sourceimpl TryFromJsValue for MazeSolutionWasm
impl TryFromJsValue for MazeSolutionWasm
Sourceimpl VectorFromWasmAbi for MazeSolutionWasm
impl VectorFromWasmAbi for MazeSolutionWasm
type Abi = <Box<[JsValue]> as FromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[MazeSolutionWasm]>
Sourceimpl VectorIntoJsValue for MazeSolutionWasm
impl VectorIntoJsValue for MazeSolutionWasm
fn vector_into_jsvalue(vector: Box<[MazeSolutionWasm]>) -> JsValue
Sourceimpl VectorIntoWasmAbi for MazeSolutionWasm
impl VectorIntoWasmAbi for MazeSolutionWasm
type Abi = <Box<[JsValue]> as IntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[MazeSolutionWasm]>) -> Self::Abi
Sourceimpl WasmDescribeVector for MazeSolutionWasm
impl WasmDescribeVector for MazeSolutionWasm